
DeNova Safecopy
---------------

Safecopy syncronizes drives and directories very carefully.
Rsync replacement that fixes rsync's fatal default metadata check.


[Documentation](https://denova.com/open_source/safecopy/ "DeNova Safecopy")
